"""

 MIT License

 Copyright (c) 2020 Benjamin Collins (kion @ dashgl.com)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.

"""

import os
import struct

class NinjaTexture: # {

	def __init__(self, filename): # {

		# File Information
		self.path = 'input/' + filename
		self.file = open(self.path, 'rb')
		self.length = os.path.getsize(self.path)

		# Textures
		self.tex_list = []
		self.pal_list = []

		return None

	def parse(self):
		print("Parsing the texture file")
		bytes = self.file.read(4)

		if bytes == 'PVMH':
			self.readPvm()
		elif bytes == 'PVRT':
			bytes = self.file.read(4)
			p = struct.unpack('I', bytes)
			pvrt_len = p[0]
			self.readPvr()
		
		return None

	def readPvm(self):
		
		bytes = self.file.read(4)
		p = struct.unpack('I', bytes)
		pvmh_len = p[0]
		save_pos = self.file.tell()
		
		bytes = self.file.read(4)
		p = struct.unpack('HH', bytes)
		flags = p[0]
		tex_count = p[1]
		
		local_list = []
		for i in range(tex_count):
			bytes = self.file.read(2)
			p = struct.unpack('H', bytes)
			tex = { 'id' : p[0] }

			if flags & 0x08:
				bytes = self.file.read(0x1c)
				tex['name'] = bytes.replace('\x00', '')
			if flags & 0x04:
				bytes = self.file.read(2)
				p = struct.unpack('H', bytes)
				tex['format'] = p[0]
			if flags & 0x02:
				bytes = self.file.read(2)
				p = struct.unpack('H', bytes)
				tex['size'] = p[0]
			if flags & 0x01:
				bytes = self.file.read(4)
				p = struct.unpack('I', bytes)
				tex['guid'] = p[0]

			local_list.append(tex)
		self.file.seek(pvmh_len + save_pos, 0)

		for tex in local_list:
			while self.file.tell() < self.length:
				bytes = self.file.read(4)
				if bytes != 'PVRT':
					continue
				break
			bytes = self.file.read(4)
			p = struct.unpack('I', bytes)
			save_pos = self.file.tell()
			pvrt_len = p[0]
			print("Reading Texture: %d" % tex['id'])
			self.readPvr(tex)
			self.file.seek(pvrt_len + save_pos, 0)

		return None

	def readPvr(self, info):
		print(info)
		return None
